@@ -15,6 +15,7 @@
 import logging
 
 from openstackclient.identity import common as identity_common
+from osc_lib.cli import format_columns
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils as oscutils
@@ -211,6 +212,16 @@ class ShowShareNetwork(command.ShowOne):
 
         data = share_network._info
 
+        # Special mapping for columns to make the output easier to read:
+        # 'metadata' --> 'properties'
+        for ss in data['share_network_subnets']:
+            ss.update(
+                {
+                    'properties':
+                        format_columns.DictColumn(ss.pop('metadata', {})),
+                },
+            )
+
         # Add security services information
         security_services = share_client.security_services.list(
             search_opts={'share_network_id': share_network.id}, detailed=False)
@@ -297,13 +308,16 @@ class CreateShareNetwork(command.ShowOne):
         elif parsed_args.availability_zone:
             availability_zone = parsed_args.availability_zone
 
-        share_network = share_client.share_networks.create(
-            name=parsed_args.name,
-            description=parsed_args.description,
-            neutron_net_id=parsed_args.neutron_net_id,
-            neutron_subnet_id=parsed_args.neutron_subnet_id,
-            availability_zone=availability_zone,
-        )
+        kwargs = {
+            "name": parsed_args.name,
+            "description": parsed_args.description,
+            "neutron_net_id": parsed_args.neutron_net_id,
+            "neutron_subnet_id": parsed_args.neutron_subnet_id,
+        }
+        if availability_zone:
+            kwargs['availability_zone'] = availability_zone
+        share_network = share_client.share_networks.create(**kwargs)
+
         share_network_data = share_network._info
         share_network_data.pop('links', None)
         if parsed_args.formatter == 'table':
